@@ -1,10 +1,20 @@
 from viadot.flows import ADLSToAzureSQL
 
 
-def test_get_promoted_adls_path_file():
+def test_get_promoted_adls_path_csv_file():
     adls_path_file = "raw/supermetrics/adls_ga_load_times_fr_test/2021-07-14T13%3A09%3A02.997357%2B00%3A00.csv"
     flow = ADLSToAzureSQL(name="test", adls_path=adls_path_file)
     promoted_path = flow.get_promoted_path(env="conformed")
+    assert (
+        promoted_path
+        == "conformed/supermetrics/adls_ga_load_times_fr_test/2021-07-14T13%3A09%3A02.997357%2B00%3A00.csv"
+    )
+
+
+def test_get_promoted_adls_path_parquet_file():
+    adls_path_file = "raw/supermetrics/adls_ga_load_times_fr_test/2021-07-14T13%3A09%3A02.997357%2B00%3A00.parquet"
+    flow = ADLSToAzureSQL(name="test", adls_path=adls_path_file)
+    promoted_path = flow.get_promoted_path(env="conformed")
     assert promoted_path == "conformed/supermetrics/adls_ga_load_times_fr_test.csv"
 
 
