@@ -4,15 +4,16 @@ import pandas as pd
 import pytest
 
 from viadot.tasks import SQLiteInsert, SQLiteSQLtoDF
-from viadot.tasks.sqlite import SQLiteInsert, SQLiteSQLtoDF
+from viadot.tasks.sqlite import SQLiteInsert, SQLiteSQLtoDF, SQLiteQuery
 
-TABLE = "test"
+TABLE = "test_sqlite_task"
 DB_PATH = "testfile.sqlite"
 SQL_PATH_SELECT = "testfile_select.sql"
 SQL_PATH_NOTSELECT = "testfile_notselect.sql"
 
-sqlite_insert_task = SQLiteInsert()
+sqlite_insert_task = SQLiteInsert(db_path=DB_PATH)
 sql_to_df_task = SQLiteSQLtoDF(db_path=DB_PATH)
+sqlite_query_task = SQLiteQuery(db_path=DB_PATH)
 
 
 @pytest.fixture(scope="session")
@@ -36,9 +37,7 @@ def test_query_select(create_test_sql_file_select):
     df_data = pd.DataFrame({"country": ["italy"], "sales": [100.0]})
     result = sqlite_insert_task.run(
         table_name=TABLE,
-        schema=None,
         dtypes=dtypes,
-        db_path=DB_PATH,
         df=df_data,
         if_exists="replace",
     )
