@@ -1,7 +1,6 @@
 from viadot.sources import CloudForCustomers
 
 import os
-import numpy
 import pytest
 
 
@@ -19,18 +18,20 @@ def cloud_for_customers():
     os.remove(TEST_FILE_1)
 
 
+def test_to_df(cloud_for_customers):
+    df = cloud_for_customers.to_df(fields=["EmployeeID", "FirstName", "LastName"])
+    assert not df.empty
+    assert df.shape[1] == 3
+    assert df.shape[0] == 2
+
+
 def test_to_records(cloud_for_customers):
     data = cloud_for_customers.to_records()
     assert "EmployeeID" in data[0].keys()
-
-
-def test_to_df(cloud_for_customers):
-    df = cloud_for_customers.to_df(fields=["EmployeeID", "FirstName", "LastName"])
-    assert type(df["EmployeeID"][0]) == numpy.int64
+    assert data != []
+    assert len(data) == 2
 
 
 def test_csv(cloud_for_customers):
-    csv = cloud_for_customers.to_csv(
-        path=TEST_FILE_1, fields=["EmployeeID", "FirstName", "LastName"]
-    )
+    csv = cloud_for_customers.to_csv(path=TEST_FILE_1)
     assert os.path.isfile(TEST_FILE_1) == True
